@@ -1,10 +1,10 @@
-
 #' @title Run statnetWeb
 #'
 #' @description Runs the statnetWeb shiny application, a GUI for the statnet
 #' suite of network analysis packages.
 #'
-#' @keywords GUI, shiny
+#' @keywords graphs datagen models
+#' @concept networks GUI shiny ergm
 #' @export
 #' @examples
 #' \dontrun{
@@ -13,5 +13,5 @@
 #'
 #'
 run_sw <- function() {
-  shiny::runApp(system.file("shiny", package = "statnetWeb"))
-}
\ No newline at end of file
+  shiny::runApp(system.file("shiny/statnetWeb", package = "statnetWeb"))
+}
